document.addEventListener('DOMContentLoaded', () => {
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');
  let questions = [];
  let currentQuestionIndex = 0;

  // Mobile menu toggle
  menuToggle.addEventListener('click', () => {
    navLinks.classList.toggle('active');
  });

  // Question template generator
  function createQuestionTemplate() {
    return {
      question: '',
      options: ['', '', '', ''],
      correctAnswer: 0,
      explanation: ''
    };
  }

  // Add new question
  document.querySelector('.add-question').addEventListener('click', () => {
    const questionContainer = document.getElementById('questions-container');
    const questionIndex = questions.length;
    questions.push(createQuestionTemplate());

    const questionElement = document.createElement('div');
    questionElement.className = 'question-item';
    questionElement.innerHTML = `
      <div class="question-header">
        <h3>Question ${questionIndex + 1}</h3>
        <button class="delete-question" data-index="${questionIndex}">×</button>
      </div>
      <textarea class="question-text" placeholder="Enter question text"></textarea>
      <div class="options">
        ${Array(4).fill('').map((_, i) => `
          <div class="option">
            <input type="radio" name="correct-${questionIndex}" value="${i}" id="q${questionIndex}-o${i}">
            <textarea placeholder="Option ${i + 1}"></textarea>
          </div>
        `).join('')}
      </div>
      <textarea class="explanation" placeholder="Enter explanation for the correct answer"></textarea>
    `;

    questionContainer.appendChild(questionElement);
    setupQuestionListeners(questionElement, questionIndex);
  });

  // Setup question event listeners
  function setupQuestionListeners(element, index) {
    const questionText = element.querySelector('.question-text');
    const optionInputs = element.querySelectorAll('.option textarea');
    const explanation = element.querySelector('.explanation');
    const correctRadios = element.querySelectorAll('input[type="radio"]');

    questionText.addEventListener('input', (e) => {
      questions[index].question = e.target.value;
    });

    optionInputs.forEach((input, i) => {
      input.addEventListener('input', (e) => {
        questions[index].options[i] = e.target.value;
      });
    });

    correctRadios.forEach((radio) => {
      radio.addEventListener('change', (e) => {
        questions[index].correctAnswer = parseInt(e.target.value);
      });
    });

    explanation.addEventListener('input', (e) => {
      questions[index].explanation = e.target.value;
    });

    element.querySelector('.delete-question').addEventListener('click', () => {
      questions.splice(index, 1);
      element.remove();
      updateQuestionNumbers();
    });
  }

  // Update question numbers after deletion
  function updateQuestionNumbers() {
    document.querySelectorAll('.question-item').forEach((item, index) => {
      item.querySelector('h3').textContent = `Question ${index + 1}`;
    });
  }

  // Save quiz
  document.querySelector('.save-quiz').addEventListener('click', () => {
    if (questions.length === 0) {
      alert('Please add at least one question.');
      return;
    }

    if (questions.some(q => !isQuestionComplete(q))) {
      alert('Please complete all questions with options and explanations.');
      return;
    }

    localStorage.setItem('currentQuiz', JSON.stringify(questions));
    document.querySelector('.quiz-creator').classList.add('hidden');
    document.querySelector('.quiz-taker').classList.remove('hidden');
    showQuestion(0);
  });

  // Check if question is complete
  function isQuestionComplete(question) {
    return question.question &&
           question.options.every(opt => opt.trim() !== '') &&
           question.explanation;
  }

  // Show question
  function showQuestion(index) {
    const question = questions[index];
    const container = document.getElementById('current-question');
    
    container.innerHTML = `
      <h3>Question ${index + 1} of ${questions.length}</h3>
      <p class="question-text">${question.question}</p>
      <div class="options">
        ${question.options.map((opt, i) => `
          <label class="option">
            <input type="radio" name="answer" value="${i}">
            <span>${opt}</span>
          </label>
        `).join('')}
      </div>
    `;

    updateProgress();
  }

  // Update progress bar
  function updateProgress() {
    const progress = ((currentQuestionIndex + 1) / questions.length) * 100;
    document.querySelector('.progress').style.width = `${progress}%`;
  }

  // Navigation
  document.querySelector('.prev-question').addEventListener('click', () => {
    if (currentQuestionIndex > 0) {
      currentQuestionIndex--;
      showQuestion(currentQuestionIndex);
    }
  });

  document.querySelector('.next-question').addEventListener('click', () => {
    if (currentQuestionIndex < questions.length - 1) {
      currentQuestionIndex++;
      showQuestion(currentQuestionIndex);
    }
  });

  // Submit quiz
  document.querySelector('.submit-quiz').addEventListener('click', () => {
    const answers = [];
    let score = 0;

    questions.forEach((q, i) => {
      const selected = document.querySelector(`input[name="answer"]:checked`);
      const answer = selected ? parseInt(selected.value) : -1;
      answers.push(answer);
      
      if (answer === q.correctAnswer) score++;
    });

    showResults(score, answers);
  });

  // Show results
  function showResults(score, answers) {
    document.querySelector('.quiz-taker').classList.add('hidden');
    document.querySelector('.quiz-results').classList.remove('hidden');

    const percentage = (score / questions.length) * 100;
    const summary = document.querySelector('.score-summary');
    const feedback = document.querySelector('.detailed-feedback');

    summary.innerHTML = `
      <h3>Your Score: ${score}/${questions.length} (${percentage.toFixed(1)}%)</h3>
    `;

    feedback.innerHTML = questions.map((q, i) => `
      <div class="question-feedback ${answers[i] === q.correctAnswer ? 'correct' : 'incorrect'}">
        <h4>Question ${i + 1}</h4>
        <p>${q.question}</p>
        <p>Your answer: ${answers[i] >= 0 ? q.options[answers[i]] : 'Not answered'}</p>
        <p>Correct answer: ${q.options[q.correctAnswer]}</p>
        <p class="explanation">${q.explanation}</p>
      </div>
    `).join('');
  }
});
